# auto-tmux

a tool to automate tmux session configurations. this tool is similar to [tmuxinator](https://github.com/tmuxinator/tmuxinator) but less mature. plus side it is written in a less archaic language.

## TODO

- [x] Publish to PYPI
  - [x] Add automation to github acitons
- [ ] add variable to yaml config files (see [todo file](./TODO.md) for more)
